function y = Q_value(x)
% 
% Usage: y = Q_value(x)
% 
% This is to calulate Q value from a simulated BER.
% This module is used within 
% 'qnber_(no)ISI, 'QnBER_(no)ISI_FixedSampleTime' or ''QnBER_(no)ISI_Optimum' modules.
% Those modules calculate BER first, (generate
% 'ber_sim.mat' which contains the variable, 'log_ber')
% and then calculate Q value using function 'fzero'.  
% 
% BER = (1/2)*erfc(Q/sqrt(2)) ~ exp(-Q^2/2)/(Q*sqrt(2*pi))   ---- (1);
% Then,
% Q^2 + 2*log(Q) + 2*log(BER) + 2*log(sqrt(2*pi)) = 0
% where
% BER = simulated one
% Q = corresponding value according to eq.(1)
%
% Note1) Output Q value is different from the conventionally defined one, that is, Q_convention = (mean(1)- mean(0))/(std(1)+ std(0)).
% Note2) The function should be used with 'fzero' to find the Q value.
%
%------------------------------------------------------------
% $ Revision: 1.0 $ Date: 2011/02/22 by Jong-Hyung Lee  
%------------------------------------------------------------

% load file ber_sim.mat which contains the variable, 'log_ber'
load ber_sim  ; %load simulated BER value (actually load its logrithm value.)

y = x.^2 + 2*log(x) + 2*log_ber + log(2*pi);
