function y = RFSpectrumAnalyzer(Input_Electrical,Res_FilterBW,Res_Filter)
%
% Usage: y = RFSpectrumAnalyzer(Input_Electrical,Res_FilterBW,Res_Filter)
% Note) y[W] = Calculated power of Input_Electrical. Use semicolon(;) to suppress it.

% Purpose = This module is to plot RF (electrical) spectrum.
%
% Input(Input_Electrical) = Electrical signal (Real)
% Output = RF Spectrum (Resolution Filter Shape & BW can be controlled.)
%
% === Parameters =====
%
% Res_FilterBW = Resolution filter bandwidth in Hz
%               =  BitRate/4  (default)
%
% Res_Filter = Resolution filter shape selection (Ex.) 'Rectangular','Hanning','Hamming','Gauss' etc)
%                 = 'Rectangular' (default)
%
% Note1) Max Resolution = 1/TimeWindow (when Res_FilterBW = BitRate/Bits, that is, nfft = DataLength)
% Note2) df = Res_FilterBW if rel_width = 2^n form 
%----------------------------------------------------------
% $ Revision: 1.3 $ Date: 2012/04/01 by Jong-Hyung Lee  
% 
%==========================================================================
global SampleRate BitRate

if isreal(Input_Electrical) == 0  ; % 
   error('Input signal is NOT real!');
end

[a,b] = size(Input_Electrical);

if a ~= 1  ; % 
        error('Please check the size of Input Electrical Signal.')
end

if nargin<3,
   Res_Filter = 'Rectangular';
end

if nargin<2,
  Res_FilterBW = BitRate/4;
end

%-----------------------------------------------------------
rel_width = SampleRate/Res_FilterBW;
nfft = round(rel_width); %'round' makes 'rel_width' an interger. Ideally, it should be a 2^n form to speed up.
% Resolution of PSD estimator will be 'SampleRate/nfft'

%==========================================================================

if strcmp(Res_Filter,'Rectangular') == 1
   window_s = rectwin(nfft);
   
elseif strcmp(Res_Filter,'Hanning') == 1   
   window_s = hanning(nfft);
   
elseif strcmp(Res_Filter,'Hamming') == 1
   window_s = hamming(nfft);   

elseif strcmp(Res_Filter,'Gauss') == 1 
   window_s = gausswin(nfft);   
 
else
 
    error('Please check your spelling.') 
                          
end

   % Overlap Percentange = 50
   [P_dens,f] = pwelch(Input_Electrical,window_s,50, nfft,SampleRate);% 
   
   % df = Res_FilterBW if rel_width = 2^n form 
   % f= 0:df:(SampleRate/2),  	
      
   df=f(2)-f(1);
   P_per_Hz = 10*log10(df*P_dens)+30; % power within each df, +30 is for dBm unit
   P_max = max(P_per_Hz); P_min = min(P_per_Hz);
   x_text = (max(f)-min(f))/5; y_d = P_max - P_min; 
   
   figure 
   plot(f,P_per_Hz)
   xlabel('Relative frequency [Hz]');ylabel('Power[dBm]')
   ResolutionBW_display = sprintf('%0.4g',Res_FilterBW);
   text(x_text,P_max-0.2*y_d,['ResolutionBW =  ' num2str(ResolutionBW_display) '[Hz]'])
   title('RF Spectrum')
       
   y = df*sum(P_dens);% Power calculated in [W]
