function y = WDM_Mux_Rect(Optical_composite,Rec_BW,IL) 
%
% Usage: y = WDM_Mux_Rect(Optical_composite,Rec_BW,IL)
%
% Purpose = This module represents a Mux with rectangular shaped optical filters.
%
% Input Signal(Optical_composite) = (Composite) Optical Signal (size = [ChannelNumber x DataLength])
% Output Signal(y) = Optical Signal (size = [1 x DataLength])
%
% ==== Physical Parameters ===== 
%   Rec_BW = Bandwidth of the filter [Hz]
%          = 4*BitRate (default) 
%   IL  = insertion loss [dB]
%       = 3 (default)
%
% Note1) All the filter characteristicas (shape, bandwidth,and IL) are assumed equal.
% Note2) Filter spacing is uniform.
%
%----------------------------------------------------------
% $ Revision: 1.1 $ Date: 2011/02/22 by Jong-Hyung Lee
%------------------------------------------------------------
%====================================================================================
global BitRate ChannelNumber ChannelSpacing

if nargin<3
    IL = 3;
end
if nargin<2,
 Rec_BW = 4*BitRate;
end


[a,b] = size(Optical_composite);

if a == 1  ; %single channel case
   Optical_input = Optical_composite;
else
   Optical_input = sum(Optical_composite); %Ideal Muxing
end

FilterNumber = ChannelNumber;
FilterSpacing = ChannelSpacing;

if FilterNumber == 1
   
    x = OpticalFilter_Rectangular(Optical_input,0,Rec_BW);
    y = Attenuator(x,IL);
    
else
    
    for k = 1:FilterNumber
    
          FilterCenter(k) = FilterSpacing*(k - (FilterNumber+1)/2);
          x(k,:) = OpticalFilter_Rectangular(Optical_input,FilterCenter(k),Rec_BW);%     
       
     end  
     
     filtered_x = sum (x);
     y = Attenuator(filtered_x,IL);
      
 end    
    
